# Changelog

## 0.2.1 (2026-03-20)

Full Changelog: [v0.2.0...v0.2.1](https://github.com/Ahmadjamil888/Pipeline_SDK/compare/v0.2.0...v0.2.1)

### Bug Fixes

* sanitize endpoint path params ([e72b971](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/e72b971e052071dad810aaa0a8a08f964867c82c))

## 0.2.0 (2026-03-19)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/Ahmadjamil888/Pipeline_SDK/compare/v0.1.0...v0.2.0)

### Features

* **api:** manual updates ([0164199](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/016419916451f105b6518903bd9e747e0b70c68e))
* **api:** manual updates ([5a0be9d](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/5a0be9dc9b3e5c5ceb5720156e5fa5c90c21ad82))
* **api:** manual updates ([84a58f3](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/84a58f3fffba2ce9a87852334cc8ed0a7999ea79))
* **api:** manual updates ([3900ea2](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/3900ea2ef0b4e7ff843ea0f5394f8496e446899c))
* **api:** manual updates ([9d5b779](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/9d5b7790ac6bea6a26b670dd32afe443db976be3))
* **api:** manual updates ([8de66e6](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/8de66e66378adddbb49abb20db5eb136d47b7218))
* **api:** manual updates ([a4344a5](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/a4344a5a098b705092d4a76060125996383c0da8))
* **api:** manual updates ([427594d](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/427594da947768391366d5e77990824793b8819b))


### Bug Fixes

* **deps:** bump minimum typing-extensions version ([89c552c](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/89c552c652b87f356cfafe3934a555da9e0cc22d))
* **pydantic:** do not pass `by_alias` unless set ([84997bb](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/84997bbfbcbbfecb9ebe02c66f7c6db1b3db4068))


### Chores

* **ci:** skip uploading artifacts on stainless-internal branches ([0c547e3](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/0c547e303fa9c1047843cf149386f0814503801f))
* **internal:** tweak CI branches ([ac1231e](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/ac1231e39c3c5efe623bc1a6808dba9b08d83ab5))
* update SDK settings ([0b076e2](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/0b076e23c2fa3034f9f12bb9ab7a298be803aa96))

## 0.1.0 (2026-03-05)

Full Changelog: [v0.0.4...v0.1.0](https://github.com/Ahmadjamil888/Pipeline_SDK/compare/v0.0.4...v0.1.0)

### Features

* **api:** manual updates ([f9bbd26](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/f9bbd26ca60cf7dd50e0a2e9c5e3cec2572c7b20))


### Chores

* **internal:** refactor authentication internals ([d639e6c](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/d639e6cd7114f7382de8e49ba7ccc3a05c16b020))
* update SDK settings ([00a4d37](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/00a4d3783e31693efd9b141780b001c6017b472e))
* update SDK settings ([f9592f3](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/f9592f3110d0cc4c191f9f1d70927ddd7122ebeb))

## 0.0.4 (2026-03-01)

Full Changelog: [v0.0.3...v0.0.4](https://github.com/Ahmadjamil888/Pipeline_SDK/compare/v0.0.3...v0.0.4)

### Chores

* update SDK settings ([e57b2ff](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/e57b2ff96cdaccf222f644f37084ff0917d3e31b))
* update SDK settings ([f2869a7](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/f2869a734b32761963f003390886c3d167835f2f))

## 0.0.3 (2026-03-01)

Full Changelog: [v0.0.2...v0.0.3](https://github.com/Ahmadjamil888/Pipeline_SDK/compare/v0.0.2...v0.0.3)

### Chores

* update SDK settings ([da651de](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/da651de5c11e62312a8e02767dc2e692226503e3))
* update SDK settings ([aa0281a](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/aa0281a49219e5dca8662788b2717d86b7795ba5))

## 0.0.2 (2026-02-28)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/Ahmadjamil888/Pipeline_SDK/compare/v0.0.1...v0.0.2)

### Chores

* update SDK settings ([95537b2](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/95537b280779211f9468be7f8b1d2b11da9e3a6c))
* update SDK settings ([50439ed](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/50439ed2a66726930607e6b8288144d44ed963eb))
* update SDK settings ([6afd1b9](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/6afd1b91d1113741e47113121e95724adbb4f274))
* update SDK settings ([5f6c7a7](https://github.com/Ahmadjamil888/Pipeline_SDK/commit/5f6c7a784531c4212ee904af375932e9a30cbd91))
